import requests


session = requests.Session()


def get(url, params={}, headers={}, cookies={}, timeout=15, retry=3) -> requests.Response:
    for c in range(retry):
        r = session.get(url, params=params, headers=headers, cookies=cookies, timeout=timeout)
        if 200 <= r.status_code <= 299:
            return r
    return r


def post(url, params={}, data='', headers={}, cookies={}, timeout=15, retry=3):
    for c in range(retry):
        r = session.post(url, params=params, data=data, headers=headers, cookies=cookies, timeout=timeout)
        if 200 <= r.status_code <= 299:
            return r
    return r


# def get(url, params={}, headers={}, cookies={}, timeout=15, retry=3, debug=False) -> requests.Response:
#     for c in range(retry):
#         try:
#             r = session.get(url, params=params, headers=headers, cookies=cookies, timeout=timeout)
#             r.raise_for_status()
#             return r
#         except requests.exceptions.HTTPError as err:
#             if not debug:
#                 print(F'({c+1}/{retry}) Http Error: {r.status_code}')
#             else:
#                 print(F'({c+1}/{retry}) Http Error:\n==========\n{err}\n{err.response.text}\n==========')
#         except requests.exceptions.ConnectionError as err:
#             if not debug:
#                 print(F'({c+1}/{retry}) Connection Error: {r.status_code}')
#             else:
#                 print(F'({c+1}/{retry}) Connection Error:\n==========\n{err}\n==========')
#         except requests.exceptions.Timeout as err:
#             if not debug:
#                 print(F'({c+1}/{retry}) Timeout Error: {r.status_code}')
#             else:
#                 print(F'({c+1}/{retry}) Timeout Error:\n==========\n{err}\n==========')
#         except requests.exceptions.TooManyRedirects as err:
#             if not debug:
#                 print(F'({c+1}/{retry}) Too Many Redirects Error: {r.status_code}')
#             else:
#                 print(F'({c+1}/{retry}) Too Many Redirects Error:\n==========\n{err}\n==========')
#         except requests.exceptions.RequestException as err:
#             if not debug:
#                 print(F'({c+1}/{retry}) Request Exception Error: {r.status_code}')
#             else:
#                 print(F'({c+1}/{retry}) Request Exception Error:\n==========\n{err}\n==========')
#     print('rGET failed')



def resize(orig, limitation, upscale=False):
    """
    Restrict image size in a given box. Return resized resolution.

    - limitation
        e.g.: (1920, 1080), (1920, -1)

    Arguments:
        orig: (w, h)
        limitation: (w, h)

    Keyword Arguments:
        upscale: Bool
            True: upscale if orig < limitation
            False: not upscale [default]

    Returns:
        (w, h)
    """

    Orig_w = orig[0]
    Orig_h = orig[1]
    Lmt_w = limitation[0]
    Lmt_h = limitation[1]

    if Lmt_w <= 0:
        if upscale is False:
            if Orig_h <= Lmt_h:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_h * Orig_w / Orig_h, Lmt_h)  # (Orig_w / (Orig_h / Lmt_h), Lmt_h)
        else:
            return (Lmt_h * Orig_w / Orig_h, Lmt_h)
    elif Lmt_h <= 0:
        if upscale is False:
            if Orig_w <= Lmt_w:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_w, Lmt_w * Orig_h / Orig_w)  # (Lmt_w, Orig_h / (Orig_w / Lmt_w))
        else:
            return (Lmt_w, Lmt_w * Orig_h / Orig_w)

    elif Orig_h * Lmt_w > Lmt_h * Orig_w:  # (Orig_h / Orig_w) > (Lmt_h / Lmt_w)
        if upscale is False:
            if Orig_h <= Lmt_h:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_h * Orig_w / Orig_h, Lmt_h)
        else:
            return (Lmt_h * Orig_w / Orig_h, Lmt_h)
    else:
        if upscale is False:
            if Orig_w <= Lmt_w:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_w, Lmt_w * Orig_h / Orig_w)
        else:
            return (Lmt_w, Lmt_w * Orig_h / Orig_w)



# clean text for telegram MARKDOWN_V2
def md2(text):
    for symbol in ['_', '*', '[', ']', '(', ')', '~', '`', '>', '#', '+', '-', '=', '|', '{', '}', '.', '!']:
        if symbol in text:
            text = text.replace(symbol, RF'\{symbol}')
    return text



class SQLite:
    def __init__(self, database, logger):
        self.database = database
        self.cursor = database.cursor()
        self.logger = logger

    def get(self, table, searchColumn, searchValue):
        try:
            SQLline = F"SELECT * FROM `{table}` WHERE `{searchColumn}` = '{searchValue}';"
            self.cursor.execute(SQLline)
            result = self.cursor.fetchone()
            return result
        except:
            logline = F"SQLite get failed!\n{SQLline}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def getall(self, table, searchColumn, searchValue):
        try:
            SQLline = F"SELECT * FROM `{table}` WHERE `{searchColumn}` = '{searchValue}';"
            self.cursor.execute(SQLline)
            result = self.cursor.fetchall()
            return result
        except:
            logline = F"SQLite getall failed!\n{SQLline}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def update(self, table, updateColumn, updateValue, searchColumn, searchValue):
        try:
            SQLline = F"UPDATE `{table}` SET `{updateColumn}` = '{updateValue}' WHERE `{searchColumn}` = '{searchValue}';"
            self.cursor.execute(SQLline)
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite update failed!\n{SQLline}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def insert(self, table, columns, values):
        try:
            SQLline = F"""INSERT INTO `{table}` (`{'`,`'.join(columns.split(','))}`) VALUES ('{"','".join(values.split(','))}');"""
            self.cursor.execute(SQLline)
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite insert failed!\n{SQLline}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def query(self, SQLline):
        try:
            self.cursor.execute(str(SQLline))
            result = self.cursor.fetchall()
            return result
        except:
            logline = F"SQLite query failed!\n{str(SQLline)}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def exec(self, SQLline):
        try:
            self.cursor.execute(str(SQLline).strip())
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite exec failed!\n{str(SQLline)}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()


class MySQL:
    def __init__(self, database, cursor, logger=False):
        self.database = database
        self.cursor = cursor
        self.logger = logger

    def get(self, table, searchColumn, searchValue):
        try:
            SQLline = F"SELECT * FROM `{table}` WHERE `{searchColumn}` = '{searchValue}';"
            self.database.connect()
            self.cursor.execute(SQLline)
            result = self.cursor.fetchone()
            return result
        except:
            logline = F"SQLite get failed!\n{SQLline}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def getall(self, table, searchColumn, searchValue):
        try:
            SQLline = F"SELECT * FROM `{table}` WHERE `{searchColumn}` = '{searchValue}';"
            self.database.connect()
            self.cursor.execute(SQLline)
            result = self.cursor.fetchall()
            return result
        except:
            logline = F"SQLite getall failed!\n{SQLline}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def update(self, table, updateColumn, updateValue, searchColumn, searchValue):
        try:
            SQLline = F"UPDATE `{table}` SET `{updateColumn}` = '{updateValue}' WHERE `{searchColumn}` = '{searchValue}';"
            self.database.connect()
            self.cursor.execute(SQLline)
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite update failed!\n{SQLline}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def insert(self, table, columns, values):
        try:
            SQLline = F"""INSERT INTO `{table}` (`{'`,`'.join(columns.split(','))}`) VALUES ('{"','".join(values.split(','))}');"""
            self.database.connect()
            self.cursor.execute(SQLline)
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite insert failed!\n{SQLline}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def query(self, SQLline):
        try:
            self.database.connect()
            self.cursor.execute(str(SQLline))
            result = self.cursor.fetchall()
            return result
        except:
            logline = F"SQLite query failed!\n{str(SQLline)}"
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()

    def exec(self, SQLline):
        try:
            self.database.connect()
            self.cursor.execute(str(SQLline))
            self.database.commit()
            result = self.cursor.rowcount
            return result
        except:
            logline = F"SQLite exec failed!\n{str(SQLline)}"
            self.database.rollback()
            self.database.close()
            try:
                self.logger.exception(logline)
            except:
                print(logline)
            quit()



import setuptools

with open('README.md', 'r', encoding='utf8') as f:
    long_description = f.read()

setuptools.setup(
    name="azunyan",
    version="4.6.0",
    author="Elypha",
    author_email="i@elypha.com",
    description="Some simple functions I packed for self usage",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Elypha/azunyan",
    project_urls={
        "Bug Tracker": "https://github.com/Elypha/azunyan/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.9",
)

## upgrade
# python -m pip install --user --upgrade setuptools wheel twine pip

## pack source distrib & wheels
# python setup.py sdist bdist_wheel

## upload
# python -m twine upload dist/*

## clean
# echo src/azunyan.egg-info build dist | rm -r

## upgrade
# python -m pip install --upgrade azunyan -i https://pypi.org/simple/
